@@ -2,7 +2,6 @@ from django import template
 
 from ..rulesets import default_rules
 
-
 register = template.Library()
 
 
@@ -13,7 +12,7 @@ def test_rule(name, obj=None, target=None):
 
 @register.simple_tag
 def has_perm(perm, user, obj=None):
-    if not hasattr(user, 'has_perm'):  # pragma: no cover
+    if not hasattr(user, "has_perm"):  # pragma: no cover
         return False  # swapped user model that doesn't support permissions
     else:
         return user.has_perm(perm, obj)
